@@ -12,6 +12,7 @@ from typing import (
     Callable,
     Hashable,
     Dict,
+    Set,
 )
 from robocorp_ls_core.protocols import (
     Sentinel,
@@ -154,6 +155,7 @@ class IRobotVariableMatch(Protocol):
 
 
 class INode(Protocol):
+    type: str
     lineno: int
     end_lineno: int
     col_offset: int
@@ -170,6 +172,7 @@ class INode(Protocol):
 class ILibraryImportNode(INode, Protocol):
     name: str
     alias: Optional[str]
+    args: Optional[Sequence[str]]
 
 
 class IKeywordNode(INode, Protocol):
@@ -289,15 +292,15 @@ class KeywordUsageInfo:
     ):
         self.stack = stack
         self.node = node
-        self.token = token
+        self.token = token  # This is actually the keyword name token.
         self.name = name
         self._is_argument_usage = is_argument_usage
 
     def __repr__(self):
         if self._is_argument_usage:
-            return f"KeywordUsageInfo({self.name} (argument usage))"
+            return f"KeywordUsageInfo({self.name} - {self.node.__class__.__name__} (argument usage))"
         else:
-            return f"KeywordUsageInfo({self.name})"
+            return f"KeywordUsageInfo({self.name} - {self.node.__class__.__name__})"
 
     __str__ = __repr__
 
@@ -413,11 +416,20 @@ class ISymbolKeywordInfo(Protocol):
 
 class ISymbolsCache(Protocol):
     def get_uri(self) -> Optional[str]:
-        pass
+        """
+        If we're referencing a library (and have the symbols from a libspec),
+        the uri may be None.
+        """
 
     def has_keyword_usage(self, normalized_keyword_name: str) -> bool:
         pass
 
+    def has_global_variable_definition(self, normalized_variable_name: str) -> bool:
+        pass
+
+    def has_variable_reference(self, normalized_variable_name: str) -> bool:
+        pass
+
     def get_json_list(self) -> List[ISymbolsJsonListEntry]:
         pass
 
@@ -767,6 +779,16 @@ class LibraryDependencyInfo:
         return ret
 
 
+class ISymbolsCacheReverseIndex(Protocol):
+    def get_global_variable_uri_definitions(
+        self, normalized_var_name: str
+    ) -> Optional[Set[str]]:
+        pass
+
+    def has_global_variable(self, normalized_var_name: str) -> bool:
+        pass
+
+
 class ICompletionContextDependencyGraph(Protocol):
     def add_library_infos(
         self,
@@ -886,6 +908,11 @@ class ICompletionContext(Protocol):
     def create_copy(self, doc: IRobotDocument) -> "ICompletionContext":
         pass
 
+    def create_copy_doc_line_col(
+        self, doc: IRobotDocument, line: int, col: int
+    ) -> "ICompletionContext":
+        pass
+
     @property
     def original_doc(self) -> IRobotDocument:
         pass
@@ -1031,6 +1058,9 @@ class ICompletionContext(Protocol):
     ) -> Iterator[IRobotDocument]:
         pass
 
+    def obtain_symbols_cache_reverse_index(self) -> Optional[ISymbolsCacheReverseIndex]:
+        pass
+
 
 class VariableKind:
     VARIABLE = "Variable"
