@@ -3,44 +3,68 @@ Constants that help in describing the accepted structure of a file.
 """
 from typing import Tuple, Dict
 import os
+from functools import lru_cache
 
 BDD_PREFIXES = ["given ", "when ", "then ", "and ", "but "]
 VARIABLE_PREFIXES = ("@", "%", "$", "&")
 
+ROBOT_FILE_EXTENSIONS = (".robot", ".resource")
+ROBOT_AND_TXT_FILE_EXTENSIONS = ROBOT_FILE_EXTENSIONS + (".txt",)
+LIBRARY_FILE_EXTENSIONS = (".py",)
+ALL_RELATED_FILE_EXTENSIONS = ROBOT_AND_TXT_FILE_EXTENSIONS + LIBRARY_FILE_EXTENSIONS
 
 # From: robot.variables.scopes.GlobalVariables._set_built_in_variables
 # (var name and description)
-BUILTIN_VARIABLES = [
-    ("${TEMPDIR}", "abspath(tempfile.gettempdir())"),
-    ("${EXECDIR}", "abspath('.')"),
-    ("${CURDIR}", "abspath('.')"),
-    ("${/}", "os.sep"),
-    ("${:}", "os.pathsep"),
-    ("${\\n}", "os.linesep"),
-    ("${SPACE}", " "),
-    ("${True}", "True"),
-    ("${False}", "False"),
-    ("${None}", "None"),
-    ("${null}", "None"),
-    ("${EMPTY}", ""),
-    ("${OUTPUT_DIR}", "settings.output_directory"),
-    ("${OUTPUT_FILE}", "settings.output or 'NONE'"),
-    ("${REPORT_FILE}", "settings.report or 'NONE'"),
-    ("${LOG_FILE}", "settings.log or 'NONE'"),
-    ("${DEBUG_FILE}", "settings.debug_file or 'NONE'"),
-    ("${LOG_LEVEL}", "settings.log_level"),
-    ("${PREV_TEST_NAME}", ""),
-    ("${PREV_TEST_STATUS}", ""),
-    ("${PREV_TEST_MESSAGE}", ""),
+_BUILTIN_VARIABLES = (
+    ("TEMPDIR", "abspath(tempfile.gettempdir())"),
+    ("EXECDIR", "abspath('.')"),
+    ("CURDIR", "abspath('.')"),
+    ("/", "os.sep"),
+    (":", "os.pathsep"),
+    ("\\n", "os.linesep"),
+    ("SPACE", " "),
+    ("True", "True"),
+    ("False", "False"),
+    ("None", "None"),
+    ("null", "None"),
+    ("EMPTY", ""),
+    ("OUTPUT_DIR", "settings.output_directory"),
+    ("OUTPUT_FILE", "settings.output or 'NONE'"),
+    ("REPORT_FILE", "settings.report or 'NONE'"),
+    ("LOG_FILE", "settings.log or 'NONE'"),
+    ("DEBUG_FILE", "settings.debug_file or 'NONE'"),
+    ("LOG_LEVEL", "settings.log_level"),
+    ("KEYWORD_STATUS", ""),
+    ("KEYWORD_MESSAGE", ""),
+    ("TEST_STATUS", ""),
+    ("TEST_MESSAGE", ""),
+    ("PREV_TEST_NAME", ""),
+    ("PREV_TEST_STATUS", ""),
+    ("PREV_TEST_MESSAGE", ""),
     # Also available during runtime (but not in docs?!).
-    ("${SUITE_DOCUMENTATION}", ""),
-    ("${SUITE_NAME}", ""),
-    ("${SUITE_SOURCE}", ""),
-    ("${TEST_DOCUMENTATION}", ""),
-    ("${TEST_NAME}", ""),
-    ("&{SUITE_METADATA}", ""),
-    ("@{TEST_TAGS}", ""),
-]
+    ("SUITE_DOCUMENTATION", ""),
+    ("SUITE_NAME", ""),
+    ("SUITE_SOURCE", ""),
+    ("SUITE_STATUS", ""),
+    ("SUITE_MESSAGE", ""),
+    ("TEST_DOCUMENTATION", ""),
+    ("TEST_NAME", ""),
+    ("SUITE_METADATA", ""),
+    ("TEST_TAGS", ""),
+)
+
+_RF5_BUILTIN_VARIABLES = (("OPTIONS", ""),)
+
+
+@lru_cache(None)
+def get_builtin_variables():
+    from robotframework_ls.impl.robot_version import get_robot_major_version
+
+    v = get_robot_major_version()
+    if v >= 5:
+        return _BUILTIN_VARIABLES + _RF5_BUILTIN_VARIABLES
+    return _BUILTIN_VARIABLES
+
 
 # i.e.: Just the variables we can resolve statically...
 BUILTIN_VARIABLES_RESOLVED = dict(
@@ -243,6 +267,7 @@ WHILE = "WHILE"
 RETURN_STATEMENT = "RETURN STATEMENT"
 CONTINUE = "CONTINUE"
 BREAK = "BREAK"
+OPTION = "OPTION"
 
 SEPARATOR = "SEPARATOR"
 COMMENT = "COMMENT"
