@@ -357,6 +357,15 @@ class Range(_Base):
     def __ne__(self, other):
         return not (self == other)
 
+    @classmethod
+    def create_from_range_typed_dict(cls, dct: RangeTypedDict) -> "Range":
+        start = Position(dct["start"]["line"], dct["start"]["character"])
+        end = Position(dct["end"]["line"], dct["end"]["character"])
+        return Range(start, end)
+
+    def is_inside(self, another_range: "Range") -> bool:
+        return self.start >= another_range.start and self.end <= another_range.end
+
 
 class TextDocumentContentChangeEvent(_Base):
     def __init__(
@@ -501,6 +510,11 @@ class PrepareRenameParamsTypedDict(TextDocumentPositionParamsTypedDict):
     pass
 
 
+class SelectionRangeParamsTypedDict(TypedDict):
+    textDocument: TextDocumentIdentifierTypedDict
+    positions: List[PositionTypedDict]
+
+
 class RenameParamsTypedDict(TypedDict, total=False):
     textDocument: TextDocumentIdentifierTypedDict
     position: PositionTypedDict
@@ -749,6 +763,13 @@ class CodeLensTypedDict(TypedDict, total=False):
     data: Optional[Any]
 
 
+class SelectionRangeTypedDict(TypedDict, total=False):
+    range: RangeTypedDict
+
+    # Actually "SelectionRangeTypedDict", but mypy doesn't support it.
+    parent: Optional[Any]
+
+
 class FoldingRangeTypedDict(TypedDict, total=False):
     """
     Represents a folding range. To be valid, start and end line must be bigger
