@@ -32,6 +32,8 @@ ENV_OPTION_LSP_DEBUG_PROCESS_ENVIRON = "LSP_DEBUG_PROCESS_ENVIRON"
 
 ENV_OPTION_LSP_DEBUG_REMOTE_FS_MESSAGES = "LSP_DEBUG_FS_MESSAGES"
 
+ENV_OPTION_LSP_DEBUG_CACHE_DEPS = "LSP_DEBUG_CACHE_DEPS"
+
 
 class BaseOptions(object):
 
@@ -44,6 +46,7 @@ class BaseOptions(object):
     DEBUG_MESSAGE_MATCHERS = is_true_in_env(ENV_OPTION_LSP_DEBUG_MESSAGE_MATCHERS)
     DEBUG_PROCESS_ENVIRON = is_true_in_env(ENV_OPTION_LSP_DEBUG_PROCESS_ENVIRON)
     DEBUG_REMOTE_FS_MESSAGES = is_true_in_env(ENV_OPTION_LSP_DEBUG_REMOTE_FS_MESSAGES)
+    DEBUG_CACHE_DEPS = is_true_in_env(ENV_OPTION_LSP_DEBUG_CACHE_DEPS)
 
     HIDE_COMMAND_MESSAGES = set()
 
