@@ -1,8 +1,13 @@
 import os.path
-import sys
 from pathlib import Path
+import sys
 from typing import List, Dict
 
+from robocorp_ls_core.robotframework_log import get_logger
+
+
+log = get_logger(__name__)
+
 
 def _import_robocop():
     try:
@@ -15,6 +20,10 @@ def _import_robocop():
         sys.path.append(_robocop_dir)
         import robocop  # @UnusedImport
 
+        log.info("Using vendored Robocop")
+
+    log.info("Robocop module: %s", robocop)
+
 
 def collect_robocop_diagnostics(
     project_root: Path, ast_model, filename: str, source: str
